@@ -491,6 +491,7 @@ impl MetadataEntry {
     }
 }
 
+/// A builder for a changelog entry.
 pub struct EntryBuilder {
     root: SyntaxNode,
     package: Option<String>,
@@ -503,18 +504,21 @@ pub struct EntryBuilder {
 }
 
 impl EntryBuilder {
+    /// Set the package name
     #[must_use]
     pub fn package(mut self, package: String) -> Self {
         self.package = Some(package);
         self
     }
 
+    /// Set the package version
     #[must_use]
     pub fn version(mut self, version: Version) -> Self {
         self.version = Some(version);
         self
     }
 
+    /// Set the distribution(s)
     #[must_use]
     pub fn distributions(mut self, distributions: Vec<String>) -> Self {
         self.distributions = Some(distributions);
@@ -734,6 +738,7 @@ impl ChangeLog {
         })
     }
 
+    /// Return a builder for a new entry.
     pub fn new_entry(&mut self) -> EntryBuilder {
         let base_entry = self.first_valid_entry();
         let package = base_entry
@@ -843,6 +848,18 @@ impl ChangeLog {
         let parsed = parse(&buf);
         Ok(parsed.root().clone_for_update())
     }
+
+    pub fn write<W: std::io::Write>(&self, mut w: W) -> Result<(), Error> {
+        let buf = self.to_string();
+        w.write_all(buf.as_bytes())?;
+        Ok(())
+    }
+
+    pub fn write_to_path(&self, p: &std::path::Path) -> Result<(), Error> {
+        let mut f = std::fs::File::create(p)?;
+        self.write(f)?;
+        Ok(())
+    }
 }
 
 impl Default for ChangeLog {
@@ -1297,6 +1314,14 @@ impl Entry {
         lines.into_iter().skip_while(|it| it.is_empty())
     }
 
+    pub fn ensure_first_line(&self, line: &str) {
+        let first_line = self.change_lines().next().map(|it| it.trim().to_string());
+
+        if first_line != Some(line.to_string()) {
+            self.prepend_change_line(line);
+        }
+    }
+
     /// Return whether the entry is marked as being unreleased
     pub fn is_unreleased(&self) -> Option<bool> {
         let distro_is_unreleased = self.distributions().as_ref().map(|ds| {
@@ -1700,3 +1725,37 @@ mod auto_add_change_tests {
         );
     }
 }
+
+#[test]
+fn test_ensure_first_line() {
+    let text = r#"lintian-brush (0.35) unstable; urgency=medium
+
+  * This line already existed.
+
+  [ Jane Example ]
+  * And this one has an existing author.
+
+ -- 
+"#;
+    let mut cl = ChangeLog::read(text.as_bytes()).unwrap();
+
+    let entry = cl.entries().next().unwrap();
+    assert_eq!(entry.package(), Some("lintian-brush".into()));
+
+    entry.ensure_first_line("* QA upload.");
+    entry.ensure_first_line("* QA upload.");
+
+    assert_eq!(
+        r#"lintian-brush (0.35) unstable; urgency=medium
+
+  * QA upload.
+  * This line already existed.
+
+  [ Jane Example ]
+  * And this one has an existing author.
+
+ -- 
+"#,
+        cl.to_string()
+    );
+}
